perfume package
===============

Submodules
----------

perfume\.analyze module
-----------------------

.. automodule:: perfume.analyze
    :members:
    :undoc-members:
    :show-inheritance:

perfume\.colors module
----------------------

.. automodule:: perfume.colors
    :members:
    :undoc-members:
    :show-inheritance:

perfume\.perfume module
-----------------------

.. automodule:: perfume.perfume
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: perfume
    :members:
    :undoc-members:
    :show-inheritance:
